{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#ExomeseqStudyType.yml/ExomeseqStudyType",
                            "label": "The type of study",
                            "symbols": [
                                "#ExomeseqStudyType.yml/ExomeseqStudyType/Small Familial",
                                "#ExomeseqStudyType.yml/ExomeseqStudyType/Large Population"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/indel_resource_mills"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#main/intervals"
                },
                {
                    "type": "string",
                    "id": "#main/name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/raw_variants"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference_genome"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/resource_dbsnp"
                },
                {
                    "type": "File",
                    "id": "#main/snp_resource_1kg"
                },
                {
                    "type": "File",
                    "id": "#main/snp_resource_hapmap"
                },
                {
                    "type": "File",
                    "id": "#main/snp_resource_omni"
                },
                {
                    "type": "#ExomeseqStudyType.yml/ExomeseqStudyType",
                    "id": "#main/study_type"
                }
            ],
            "steps": [
                {
                    "run": "#GATK4-ApplyVQSR.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 10240
                        }
                    ],
                    "in": [
                        {
                            "default": true,
                            "id": "#main/apply_vqsr_indels/create_output_variant_index"
                        },
                        {
                            "default": "-Xmx5g -Xms5g",
                            "id": "#main/apply_vqsr_indels/java_opt"
                        },
                        {
                            "default": "INDEL",
                            "id": "#main/apply_vqsr_indels/mode"
                        },
                        {
                            "source": "#main/generate_joint_filenames/indels_recalibrated_variants_filename",
                            "id": "#main/apply_vqsr_indels/output_recalibrated_variants_filename"
                        },
                        {
                            "source": "#main/variant_recalibration_indels/output_recalibration",
                            "id": "#main/apply_vqsr_indels/recalibration_file"
                        },
                        {
                            "source": "#main/variant_recalibration_indels/output_tranches",
                            "id": "#main/apply_vqsr_indels/tranches_file"
                        },
                        {
                            "default": 99.7,
                            "id": "#main/apply_vqsr_indels/truth_sensitivity_filter_level"
                        },
                        {
                            "source": "#main/joint_genotyping/output_vcf",
                            "id": "#main/apply_vqsr_indels/variants"
                        }
                    ],
                    "out": [
                        "#main/apply_vqsr_indels/output_recalibrated_variants"
                    ],
                    "id": "#main/apply_vqsr_indels"
                },
                {
                    "run": "#GATK4-ApplyVQSR.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 10240
                        }
                    ],
                    "in": [
                        {
                            "default": true,
                            "id": "#main/apply_vqsr_snps/create_output_variant_index"
                        },
                        {
                            "default": "-Xmx5g -Xms5g",
                            "id": "#main/apply_vqsr_snps/java_opt"
                        },
                        {
                            "default": "SNP",
                            "id": "#main/apply_vqsr_snps/mode"
                        },
                        {
                            "source": "#main/generate_joint_filenames/combined_recalibrated_variants_filename",
                            "id": "#main/apply_vqsr_snps/output_recalibrated_variants_filename"
                        },
                        {
                            "source": "#main/variant_recalibration_indels/output_recalibration",
                            "id": "#main/apply_vqsr_snps/recalibration_file"
                        },
                        {
                            "source": "#main/variant_recalibration_indels/output_tranches",
                            "id": "#main/apply_vqsr_snps/tranches_file"
                        },
                        {
                            "default": 99.7,
                            "id": "#main/apply_vqsr_snps/truth_sensitivity_filter_level"
                        },
                        {
                            "source": "#main/apply_vqsr_indels/output_recalibrated_variants",
                            "id": "#main/apply_vqsr_snps/variants"
                        }
                    ],
                    "out": [
                        "#main/apply_vqsr_snps/output_recalibrated_variants"
                    ],
                    "id": "#main/apply_vqsr_snps"
                },
                {
                    "run": "#GATK4-CollectVariantCallingMetrics.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 12288
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/resource_dbsnp",
                            "id": "#main/collect_metrics/dbsnp"
                        },
                        {
                            "source": "#main/apply_vqsr_snps/output_recalibrated_variants",
                            "id": "#main/collect_metrics/input_vcf"
                        },
                        {
                            "default": "-Xmx6g -Xms6g",
                            "id": "#main/collect_metrics/java_opt"
                        },
                        {
                            "source": "#main/name",
                            "id": "#main/collect_metrics/output_metrics_filename_prefix"
                        },
                        {
                            "source": "#main/extract_sequence_dict/extracted",
                            "id": "#main/collect_metrics/sequence_dictionary"
                        },
                        {
                            "source": "#main/extract_intervals_file/extracted",
                            "id": "#main/collect_metrics/target_intervals"
                        },
                        {
                            "default": 8,
                            "id": "#main/collect_metrics/thread_count"
                        }
                    ],
                    "out": [
                        "#main/collect_metrics/output_detail_metrics",
                        "#main/collect_metrics/output_summary_metrics"
                    ],
                    "id": "#main/collect_metrics"
                },
                {
                    "run": "#extract-array-file.cwl",
                    "in": [
                        {
                            "source": "#main/intervals",
                            "id": "#main/extract_intervals_file/files"
                        },
                        {
                            "default": 0,
                            "id": "#main/extract_intervals_file/index"
                        }
                    ],
                    "out": [
                        "#main/extract_intervals_file/extracted"
                    ],
                    "id": "#main/extract_intervals_file"
                },
                {
                    "run": "#extract-secondary-file.cwl",
                    "in": [
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/extract_sequence_dict/file"
                        },
                        {
                            "default": ".dict",
                            "id": "#main/extract_sequence_dict/pattern"
                        }
                    ],
                    "out": [
                        "#main/extract_sequence_dict/extracted"
                    ],
                    "id": "#main/extract_sequence_dict"
                },
                {
                    "run": "#generate-variant-recalibration-annotation-set.cwl",
                    "in": [
                        {
                            "default": [
                                "FS",
                                "ReadPosRankSum",
                                "MQRankSum",
                                "QD",
                                "SOR",
                                "DP"
                            ],
                            "id": "#main/generate_annotations_indels/base_annotations"
                        },
                        {
                            "source": "#main/study_type",
                            "id": "#main/generate_annotations_indels/study_type"
                        }
                    ],
                    "out": [
                        "#main/generate_annotations_indels/annotations"
                    ],
                    "id": "#main/generate_annotations_indels"
                },
                {
                    "run": "#generate-variant-recalibration-annotation-set.cwl",
                    "in": [
                        {
                            "default": [
                                "QD",
                                "MQRankSum",
                                "ReadPosRankSum",
                                "FS",
                                "MQ",
                                "SOR",
                                "DP"
                            ],
                            "id": "#main/generate_annotations_snps/base_annotations"
                        },
                        {
                            "source": "#main/study_type",
                            "id": "#main/generate_annotations_snps/study_type"
                        }
                    ],
                    "out": [
                        "#main/generate_annotations_snps/annotations"
                    ],
                    "id": "#main/generate_annotations_snps"
                },
                {
                    "run": "#generate-joint-filenames-gatk4.cwl",
                    "in": [
                        {
                            "source": "#main/name",
                            "id": "#main/generate_joint_filenames/name"
                        }
                    ],
                    "out": [
                        "#main/generate_joint_filenames/raw_variants_filename",
                        "#main/generate_joint_filenames/snps_recalibration_filename",
                        "#main/generate_joint_filenames/snps_tranches_filename",
                        "#main/generate_joint_filenames/snps_recalibrated_variants_filename",
                        "#main/generate_joint_filenames/indels_recalibration_filename",
                        "#main/generate_joint_filenames/indels_tranches_filename",
                        "#main/generate_joint_filenames/indels_recalibrated_variants_filename",
                        "#main/generate_joint_filenames/combined_recalibrated_variants_filename"
                    ],
                    "id": "#main/generate_joint_filenames"
                },
                {
                    "run": "#GATK4-GenotypeGVCFs.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 10240
                        }
                    ],
                    "in": [
                        {
                            "default": [
                                "StandardAnnotation",
                                "AS_StandardAnnotation"
                            ],
                            "id": "#main/joint_genotyping/annotation_groups"
                        },
                        {
                            "source": "#main/resource_dbsnp",
                            "id": "#main/joint_genotyping/dbsnp"
                        },
                        {
                            "source": "#main/interval_padding",
                            "id": "#main/joint_genotyping/interval_padding"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/joint_genotyping/intervals"
                        },
                        {
                            "default": "-Xmx5g -Xms5g",
                            "id": "#main/joint_genotyping/java_opt"
                        },
                        {
                            "default": true,
                            "id": "#main/joint_genotyping/only_output_calls_starting_in_intervals"
                        },
                        {
                            "source": "#main/generate_joint_filenames/raw_variants_filename",
                            "id": "#main/joint_genotyping/output_vcf_filename"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/joint_genotyping/reference"
                        },
                        {
                            "default": true,
                            "id": "#main/joint_genotyping/use_new_qual_calculator"
                        },
                        {
                            "source": "#main/raw_variants",
                            "id": "#main/joint_genotyping/variants"
                        }
                    ],
                    "out": [
                        "#main/joint_genotyping/output_vcf"
                    ],
                    "id": "#main/joint_genotyping"
                },
                {
                    "run": "#GATK4-VariantRecalibrator.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 49152
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/generate_annotations_snps/annotations",
                            "id": "#main/variant_recalibration_indels/annotations"
                        },
                        {
                            "default": "-Xmx24g -Xms24g",
                            "id": "#main/variant_recalibration_indels/java_opt"
                        },
                        {
                            "default": "SNP",
                            "id": "#main/variant_recalibration_indels/mode"
                        },
                        {
                            "source": "#main/generate_joint_filenames/indels_recalibration_filename",
                            "id": "#main/variant_recalibration_indels/output_recalibration_filename"
                        },
                        {
                            "source": "#main/generate_joint_filenames/indels_tranches_filename",
                            "id": "#main/variant_recalibration_indels/output_tranches_filename"
                        },
                        {
                            "default": [
                                {
                                    "name": "#main/variant_recalibration_indels/resources/mills",
                                    "known": false,
                                    "training": true,
                                    "truth": true,
                                    "prior": 12,
                                    "file": "indel_resource_mills"
                                },
                                {
                                    "name": "#main/variant_recalibration_indels/resources/dbsnp",
                                    "known": true,
                                    "training": false,
                                    "truth": false,
                                    "prior": 2,
                                    "file": "resource_dbsnp"
                                }
                            ],
                            "id": "#main/variant_recalibration_indels/resources"
                        },
                        {
                            "default": [
                                "100.0",
                                "99.95",
                                "99.9",
                                "99.8",
                                "99.6",
                                "99.5",
                                "99.4",
                                "99.3",
                                "99.0",
                                "98.0",
                                "97.0",
                                "90.0"
                            ],
                            "id": "#main/variant_recalibration_indels/tranches"
                        },
                        {
                            "source": "#main/joint_genotyping/output_vcf",
                            "id": "#main/variant_recalibration_indels/variants"
                        }
                    ],
                    "out": [
                        "#main/variant_recalibration_indels/output_recalibration",
                        "#main/variant_recalibration_indels/output_tranches"
                    ],
                    "id": "#main/variant_recalibration_indels"
                },
                {
                    "run": "#GATK4-VariantRecalibrator.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 6144
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/generate_annotations_snps/annotations",
                            "id": "#main/variant_recalibration_snps/annotations"
                        },
                        {
                            "default": "-Xmx3g -Xms3g",
                            "id": "#main/variant_recalibration_snps/java_opt"
                        },
                        {
                            "default": "SNP",
                            "id": "#main/variant_recalibration_snps/mode"
                        },
                        {
                            "source": "#main/generate_joint_filenames/snps_recalibration_filename",
                            "id": "#main/variant_recalibration_snps/output_recalibration_filename"
                        },
                        {
                            "source": "#main/generate_joint_filenames/snps_tranches_filename",
                            "id": "#main/variant_recalibration_snps/output_tranches_filename"
                        },
                        {
                            "default": [
                                {
                                    "name": "#main/variant_recalibration_snps/resources/hapmap",
                                    "known": false,
                                    "training": true,
                                    "truth": true,
                                    "prior": 15,
                                    "file": "snp_resource_hapmap"
                                },
                                {
                                    "name": "#main/variant_recalibration_snps/resources/omni",
                                    "known": false,
                                    "training": true,
                                    "truth": true,
                                    "prior": 12,
                                    "file": "snp_resource_omni"
                                },
                                {
                                    "name": "#main/variant_recalibration_snps/resources/1000G",
                                    "known": false,
                                    "training": true,
                                    "truth": false,
                                    "prior": 10,
                                    "file": "snp_resource_1kg"
                                },
                                {
                                    "name": "#main/variant_recalibration_snps/resources/dbsnp",
                                    "known": true,
                                    "training": false,
                                    "truth": false,
                                    "prior": 7,
                                    "file": "resource_dbsnp"
                                }
                            ],
                            "id": "#main/variant_recalibration_snps/resources"
                        },
                        {
                            "default": [
                                "100.0",
                                "99.95",
                                "99.9",
                                "99.8",
                                "99.6",
                                "99.5",
                                "99.4",
                                "99.3",
                                "99.0",
                                "98.0",
                                "97.0",
                                "90.0"
                            ],
                            "id": "#main/variant_recalibration_snps/tranches"
                        },
                        {
                            "source": "#main/joint_genotyping/output_vcf",
                            "id": "#main/variant_recalibration_snps/variants"
                        }
                    ],
                    "out": [
                        "#main/variant_recalibration_snps/output_recalibration",
                        "#main/variant_recalibration_snps/output_tranches"
                    ],
                    "id": "#main/variant_recalibration_snps"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/collect_metrics/output_detail_metrics",
                    "id": "#main/detail_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/joint_genotyping/output_vcf",
                    "doc": "VCF file from joint genotyping calling",
                    "id": "#main/joint_raw_variants"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_metrics/output_summary_metrics",
                    "id": "#main/summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/apply_vqsr_snps/output_recalibrated_variants",
                    "doc": "The output VCF file after INDEL and SNP recalibration",
                    "id": "#main/variant_recalibration_combined_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_recalibration_indels/output_tranches",
                    "doc": "The output tranches file used by ApplyVQSR in INDEL mode",
                    "id": "#main/variant_recalibration_indels_tranches"
                },
                {
                    "type": "File",
                    "outputSource": "#main/apply_vqsr_indels/output_recalibrated_variants",
                    "doc": "The output VCF file after INDEL recalibration",
                    "id": "#main/variant_recalibration_indels_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_recalibration_indels/output_recalibration",
                    "doc": "The output recalibration file used by ApplyVQSR in INDEL mode",
                    "id": "#main/variant_recalibration_snps_indels_recalibration"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_recalibration_snps/output_recalibration",
                    "doc": "The output recalibration file used by ApplyVQSR in SNP mode",
                    "id": "#main/variant_recalibration_snps_recalibration"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_recalibration_snps/output_tranches",
                    "doc": "The output tranches file used by ApplyVQSR in SNP mode",
                    "id": "#main/variant_recalibration_snps_tranches"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-index",
                        "position": 5
                    },
                    "doc": "Trust that all the input training sets' unfiltered records contain only polymorphic sites to drastically speed up the computation.  Default value: false.",
                    "id": "#GATK4-ApplyVQSR.cwl/create_output_variant_index"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-ApplyVQSR.cwl/java_opt"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#GATK4-ApplyVQSR.cwl/mode/SNP",
                            "#GATK4-ApplyVQSR.cwl/mode/INDEL",
                            "#GATK4-ApplyVQSR.cwl/mode/BOTH"
                        ]
                    },
                    "inputBinding": {
                        "prefix": "-mode",
                        "position": 7
                    },
                    "doc": "Recalibration mode to employ  Default value: SNP. Possible values: {SNP, INDEL, BOTH}",
                    "id": "#GATK4-ApplyVQSR.cwl/mode"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 1
                    },
                    "doc": "The output filtered and recalibrated VCF file in which each variant is annotated with its VQSLOD value  Required",
                    "id": "#GATK4-ApplyVQSR.cwl/output_recalibrated_variants_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--recal-file",
                        "position": 2
                    },
                    "doc": "The input recal file used by ApplyRecalibration  Required.",
                    "id": "#GATK4-ApplyVQSR.cwl/recalibration_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--tranches-file",
                        "position": 3
                    },
                    "doc": "The input tranches file describing where to cut the data",
                    "id": "#GATK4-ApplyVQSR.cwl/tranches_file"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--truth-sensitivity-filter-level",
                        "position": 4
                    },
                    "doc": "The truth sensitivity level at which to start filtering",
                    "id": "#GATK4-ApplyVQSR.cwl/truth_sensitivity_filter_level"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "One or more VCF files containing variants  This argument must be specified at least once.",
                    "id": "#GATK4-ApplyVQSR.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_recalibrated_variants_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-ApplyVQSR.cwl/output_recalibrated_variants"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "ApplyVQSR",
                    "position": 0
                }
            ],
            "id": "#GATK4-ApplyVQSR.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--DBSNP",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "Reference dbSNP file in dbSNP or VCF format.  Required.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/dbsnp"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--INPUT",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "Input vcf file for analysis  Required.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/input_vcf"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/java_opt"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--OUTPUT",
                        "position": 4
                    },
                    "doc": "Path (except for the file extension) of output metrics files to write.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/output_metrics_filename_prefix"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--SEQUENCE_DICTIONARY",
                        "position": 3
                    },
                    "doc": "If present, speeds loading of dbSNP file, will look for dictionary in vcf if not present here.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/sequence_dictionary"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--TARGET_INTERVALS",
                        "position": 6
                    },
                    "doc": "Target intervals to restrict analysis to.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/target_intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--THREAD_COUNT",
                        "position": 5
                    },
                    "doc": "Number of threads to use (Undocumented in gatk CLI help)",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/thread_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_metrics_filename_prefix + '.variant_calling_detail_metrics')"
                    },
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/output_detail_metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_metrics_filename_prefix + '.variant_calling_summary_metrics')"
                    },
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/output_summary_metrics"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "CollectVariantCallingMetrics",
                    "position": 0
                }
            ],
            "id": "#GATK4-CollectVariantCallingMetrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-G"
                            }
                        }
                    ],
                    "doc": "One or more groups of annotations to apply to variant calls  This argument may be specified 0 or more times. Default value: [StandardAnnotation].",
                    "id": "#GATK4-GenotypeGVCFs.cwl/annotation_groups"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-D"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "dbSNP file. Default value: null",
                    "id": "#GATK4-GenotypeGVCFs.cwl/dbsnp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Amount of padding (in bp) to add to each interval you are including. Defaults to 0",
                    "inputBinding": {
                        "prefix": "-ip"
                    },
                    "id": "#GATK4-GenotypeGVCFs.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "-L"
                            }
                        }
                    ],
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GATK4-GenotypeGVCFs.cwl/intervals"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-GenotypeGVCFs.cwl/java_opt"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--only_output_calls_starting_in_intervals"
                    },
                    "doc": "Restrict variant output to sites that start within provided intervals  Default value: false.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/only_output_calls_starting_in_intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "doc": "File to which variants should be written  Required.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/output_vcf_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "doc": "Reference sequence file  Required.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-new-qual-calculator"
                    },
                    "doc": "If provided, we will use the new AF model instead of the so-called exact model  Default value: false.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/use_new_qual_calculator"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-V"
                        }
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "One or more VCF files containing variants  Required.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-GenotypeGVCFs.cwl/output_vcf"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "GenotypeGVCFs",
                    "position": 0
                }
            ],
            "id": "#GATK4-GenotypeGVCFs.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-an"
                        }
                    },
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "The names of the annotations which should used for calculations",
                    "id": "#GATK4-VariantRecalibrator.cwl/annotations"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-VariantRecalibrator.cwl/java_opt"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-gaussians",
                        "position": 8
                    },
                    "doc": "Max number of Gaussians for the positive model  Default value: 8.",
                    "id": "#GATK4-VariantRecalibrator.cwl/max_gaussians"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#GATK4-VariantRecalibrator.cwl/mode/SNP",
                            "#GATK4-VariantRecalibrator.cwl/mode/INDEL",
                            "#GATK4-VariantRecalibrator.cwl/mode/BOTH"
                        ]
                    },
                    "inputBinding": {
                        "prefix": "-mode",
                        "position": 7
                    },
                    "doc": "Recalibration mode to employ  Default value: SNP. Possible values: {SNP, INDEL, BOTH}",
                    "id": "#GATK4-VariantRecalibrator.cwl/mode"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 2
                    },
                    "doc": "The output recal file used by ApplyRecalibration  Required.",
                    "id": "#GATK4-VariantRecalibrator.cwl/output_recalibration_filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--tranches-file",
                        "position": 3
                    },
                    "doc": "The output tranches file used by ApplyRecalibration  Required.",
                    "id": "#GATK4-VariantRecalibrator.cwl/output_tranches_filename"
                },
                {
                    "inputBinding": {
                        "position": 9
                    },
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "record",
                            "name": "#GATK4-VariantRecalibrator.cwl/resources/resource",
                            "fields": [
                                {
                                    "type": "File",
                                    "name": "#GATK4-VariantRecalibrator.cwl/resources/resource/file"
                                },
                                {
                                    "type": "boolean",
                                    "name": "#GATK4-VariantRecalibrator.cwl/resources/resource/known"
                                },
                                {
                                    "type": "string",
                                    "name": "#GATK4-VariantRecalibrator.cwl/resources/resource/name"
                                },
                                {
                                    "type": "int",
                                    "name": "#GATK4-VariantRecalibrator.cwl/resources/resource/prior"
                                },
                                {
                                    "type": "boolean",
                                    "name": "#GATK4-VariantRecalibrator.cwl/resources/resource/training"
                                },
                                {
                                    "type": "boolean",
                                    "name": "#GATK4-VariantRecalibrator.cwl/resources/resource/truth"
                                }
                            ]
                        },
                        "inputBinding": {
                            "prefix": "-resource",
                            "valueFrom": "${\n  function makeResourceLine(resource) {\n    return resource.name +\n    ',known=' + (resource.known ? 'true' : 'false') +\n    ',training=' + (resource.training ? 'true' : 'false') +\n    ',truth=' + (resource.truth ? 'true' : 'false') +\n    ',prior=' + resource.prior +\n    ':' + resource.file.path;\n  }\n  return makeResourceLine(self);\n}\n"
                        }
                    },
                    "id": "#GATK4-VariantRecalibrator.cwl/resources"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-tranche"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#GATK4-VariantRecalibrator.cwl/tranches"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--trust-all-polymorphic",
                        "position": 4
                    },
                    "doc": "Trust that all the input training sets' unfiltered records contain only polymorphic sites to drastically speed up the computation.  Default value: false.",
                    "id": "#GATK4-VariantRecalibrator.cwl/trust_all_polymorphic"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "One or more VCF files containing variants  Required.",
                    "id": "#GATK4-VariantRecalibrator.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_recalibration_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-VariantRecalibrator.cwl/output_recalibration"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_tranches_filename)"
                    },
                    "id": "#GATK4-VariantRecalibrator.cwl/output_tranches"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "VariantRecalibrator",
                    "position": 0
                }
            ],
            "id": "#GATK4-VariantRecalibrator.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#extract-array-file.cwl/files"
                },
                {
                    "type": "int",
                    "id": "#extract-array-file.cwl/index"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract-array-file.cwl/extracted"
                }
            ],
            "expression": "${\n  if(inputs.files) {\n    return { \"extracted\" : inputs.files[inputs.index] };\n  } else {\n    return { \"extracted\" : null };\n  }\n}\n",
            "id": "#extract-array-file.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#extract-secondary-file.cwl/file"
                },
                {
                    "type": "string",
                    "id": "#extract-secondary-file.cwl/pattern"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract-secondary-file.cwl/extracted"
                }
            ],
            "expression": "${\n  var secondaryFiles = inputs.file.secondaryFiles;\n  var pattern = inputs.pattern;\n  var matches = secondaryFiles.filter(function(each) {\n    return each.basename.match(pattern);\n  });\n  return { \"extracted\" : matches[0] };\n}\n",
            "id": "#extract-secondary-file.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Generates a set of file names for joint steps based on an input name",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/combined_recalibrated_variants_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/indels_recalibrated_variants_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/indels_recalibration_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/indels_tranches_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/raw_variants_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/snps_recalibrated_variants_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/snps_recalibration_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/snps_tranches_filename"
                }
            ],
            "expression": "${\n  function makeFilename(base, suffix, extension) {\n    return base + '-' + suffix + '.' + extension;\n  }\n  var base = inputs.name\n\n  return {\n    raw_variants_filename: makeFilename(base, 'raw_variants', 'g.vcf'),\n    snps_recalibration_filename: makeFilename(base, 'snps_recal', 'out'),\n    snps_tranches_filename: makeFilename(base, 'snps_tranches', 'out'),\n    snps_recalibrated_variants_filename: makeFilename(base, 'snps_recal_variants', 'vcf'),\n    indels_recalibration_filename: makeFilename(base, 'indels_recal', 'out'),\n    indels_tranches_filename: makeFilename(base, 'indels_tranches', 'out'),\n    indels_recalibrated_variants_filename: makeFilename(base, 'indels_recal_variants', 'vcf'),\n    combined_recalibrated_variants_filename: makeFilename(base, 'indels_snps_recal_variants', 'vcf')\n  };\n}\n",
            "id": "#generate-joint-filenames-gatk4.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Given an ExomeseqStudyType returns an array of the annotations to use.",
            "doc": "The InbreedingCoeff is a population level statistic that requires at least 10 samples in order to be computed. For projects with fewer samples, or that includes many closely related samples (such as a family) please omit this annotation from the command line. From https://software.broadinstitute.org/gatk/documentation/article?id=1259\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#ExomeseqStudyType.yml/ExomeseqStudyType"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#generate-variant-recalibration-annotation-set.cwl/base_annotations"
                },
                {
                    "type": "#ExomeseqStudyType.yml/ExomeseqStudyType",
                    "id": "#generate-variant-recalibration-annotation-set.cwl/study_type"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#generate-variant-recalibration-annotation-set.cwl/annotations"
                }
            ],
            "expression": "${\n  var annotations = inputs.base_annotations;\n  var inputStudyType = inputs.study_type;\n  if(inputStudyType === \"Large Population\") {\n    annotations.push(\"InbreedingCoeff\");\n  }\n  return {\"annotations\": annotations };\n}\n",
            "id": "#generate-variant-recalibration-annotation-set.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
